from django.apps import AppConfig


class DjangoAdminRecentInlinesConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "django_admin_recent_inlines"
    verbose_name = "Django Admin Recent Inlines"
