"""
Django Admin Recent Inlines

A Django package that provides a RecentTabularInline class for displaying
recent related objects in Django admin with a "View All" link.
"""

__version__ = "0.1.4"
__author__ = "Konrad Beck"
__email__ = "konrad.beck@merchantcapital.co.za"

default_app_config = "django_admin_recent_inlines.apps.DjangoAdminRecentInlinesConfig"
